@@ -28,7 +28,9 @@ from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms as hz_forms
 from horizon import messages
+from openstack_dashboard.api import cinder
 from openstack_dashboard.api import glance
+from openstack_dashboard.api import neutron
 from openstack_dashboard.api import nova
 from oslo_log import log as logging
 from oslo_log import versionutils
@@ -115,8 +117,13 @@ def get_murano_images(request):
         LOG.error("Error to request image list from glance ")
         exceptions.handle(request, _("Unable to retrieve public images."))
     murano_images = []
+    # filter out the snapshot image type
+    images = filter(
+        lambda x: x.properties.get("image_type", '') != 'snapshot', images)
     for image in images:
-        murano_property = image.properties.get('murano_image_info')
+        # Additional properties, whose value is always a string data type, are
+        # only included in the response if they have a value.
+        murano_property = getattr(image, 'murano_image_info', None)
         if murano_property:
             try:
                 murano_metadata = json.loads(murano_property)
@@ -158,6 +165,8 @@ FIELD_ARGS_TO_ESCAPE = ['help_text', 'initial', 'description', 'label']
 
 
 class CustomPropertiesField(forms.Field):
+    js_validation = False
+
     def __init__(self, description=None, description_title=None,
                  *args, **kwargs):
         self.description = description
@@ -169,21 +178,46 @@ class CustomPropertiesField(forms.Field):
                 kwargs[arg] = html.escape(force_text(kwargs[arg]))
 
         validators = []
+        validators_js = []
         for validator in kwargs.get('validators', []):
             if hasattr(validator, '__call__'):  # single regexpValidator
                 validators.append(validator)
-            else:  # mixed list of regexpValidator-s and YAQL validators
+                if hasattr(validator, 'regex'):
+                    regex_message = ''
+                    error_messages = kwargs.get('error_messages', {})
+                    if hasattr(validator, 'code') and \
+                       validator.code in error_messages:
+                        regex_message = force_text(
+                            error_messages[validator.code]
+                        )
+                    validators_js. \
+                        append({'regex': force_text(validator.regex.pattern),
+                                'message': regex_message})
+            else:  # mixed list of regexpValidator and YAQL validators
                 expr = validator.get('expr')
                 regex_validator = get_regex_validator(expr)
+                regex_message = validator.get('message', '')
                 if regex_validator:
                     validators.append(wrap_regex_validator(
-                        regex_validator, validator.get('message', '')))
+                        regex_validator, regex_message))
                 elif isinstance(expr, RawProperty):
                     validators.append(validator)
+                if hasattr(regex_validator, 'regex'):
+                    validators_js.\
+                        append({'regex': regex_validator.regex.pattern,
+                                'message': regex_message})
         kwargs['validators'] = validators
+        if validators_js:
+            self.js_validation = json.dumps(validators_js)
 
         super(CustomPropertiesField, self).__init__(*args, **kwargs)
 
+    def widget_attrs(self, widget):
+        attrs = super(CustomPropertiesField, self).widget_attrs(widget)
+        if self.js_validation:
+            attrs['data-validators'] = self.js_validation
+        return attrs
+
     def clean(self, value):
         """Skip all validators if field is disabled."""
         # form is assigned in ServiceConfigurationForm.finalize_fields()
@@ -237,10 +271,6 @@ class PasswordField(CharField):
                 raise forms.ValidationError(_(u"{0}{1} don't match").format(
                     self.label, defaultfilters.pluralize(2)))
 
-    class PasswordInput(forms.PasswordInput):
-        class Media(object):
-            js = ('muranodashboard/js/passwordfield.js',)
-
     def __init__(self, label, *args, **kwargs):
         self.confirm_input = kwargs.pop('confirm_input', True)
 
@@ -264,8 +294,8 @@ class PasswordField(CharField):
                 'invalid', self.validate_password.message)
             kwargs['min_length'] = kwargs.get('min_length', 7)
             kwargs['max_length'] = kwargs.get('max_length', 255)
-            kwargs['widget'] = self.PasswordInput(attrs=self.attrs,
-                                                  render_value=True)
+            kwargs['widget'] = forms.PasswordInput(attrs=self.attrs,
+                                                   render_value=True)
         else:
             if not help_text:
                 # NOTE(kzaitsev) There are custom validators for password,
@@ -298,6 +328,19 @@ class IntegerField(forms.IntegerField, CustomPropertiesField):
     pass
 
 
+def _get_title(data):
+    if isinstance(data, Choice):
+        return data.title
+    return data
+
+
+def _disable_non_ready(data):
+    if getattr(data, 'enabled', True):
+        return {}
+    else:
+        return {'disabled': 'disabled'}
+
+
 class ChoiceField(forms.ChoiceField, CustomPropertiesField):
     def __init__(self, **kwargs):
         choices = kwargs.get('choices') or getattr(self, 'choices', None)
@@ -305,10 +348,12 @@ class ChoiceField(forms.ChoiceField, CustomPropertiesField):
             if isinstance(choices, dict):
                 choices = list(choices.items())
             kwargs['choices'] = choices
+        kwargs['widget'] = hz_forms.ThemableSelectWidget(transform=_get_title)
         super(ChoiceField, self).__init__(**kwargs)
 
 
-class DynamicChoiceField(hz_forms.DynamicChoiceField, CustomPropertiesField):
+class DynamicChoiceField(hz_forms.ThemableDynamicChoiceField,
+                         CustomPropertiesField):
     pass
 
 
@@ -365,7 +410,7 @@ class FlavorChoiceField(ChoiceField):
 
 
 class KeyPairChoiceField(DynamicChoiceField):
-    " This widget allows to select keypair for VMs "
+    """This widget allows to select keypair for VMs"""
     @with_request
     def update(self, request, **kwargs):
         self.choices = [('', _('No keypair'))]
@@ -375,6 +420,20 @@ class KeyPairChoiceField(DynamicChoiceField):
             self.choices.append((keypair.name, keypair.name))
 
 
+class SecurityGroupChoiceField(DynamicChoiceField):
+    """This widget allows to select a security group for VMs"""
+    @with_request
+    def update(self, request, **kwargs):
+        self.choices = [('', _('Application default security group'))]
+        # TODO(pbourke): remove sorted when supported natively in Horizon
+        # (https://bugs.launchpad.net/horizon/+bug/1692972)
+        for secgroup in sorted(
+                neutron.security_group_list(request),
+                key=lambda e: e.name_or_id):
+            if not secgroup.name_or_id.startswith('murano--'):
+                self.choices.append((secgroup.name_or_id, secgroup.name_or_id))
+
+
 # NOTE(kzaitsev): for transform to work correctly on horizon SelectWidget
 # Choice has to be non-string
 class Choice(object):
@@ -384,22 +443,10 @@ class Choice(object):
         self.enabled = enabled
 
 
-def _get_title(data):
-    if isinstance(data, Choice):
-        return data.title
-    return data
-
-
-def _disable_non_ready(data):
-    if getattr(data, 'enabled', True):
-        return {}
-    else:
-        return {'disabled': 'disabled'}
-
-
 class ImageChoiceField(ChoiceField):
-    widget = hz_forms.SelectWidget(transform=_get_title,
-                                   transform_html_attrs=_disable_non_ready)
+    widget = hz_forms.ThemableSelectWidget(
+        transform=_get_title,
+        transform_html_attrs=_disable_non_ready)
 
     def __init__(self, *args, **kwargs):
         self.image_type = kwargs.pop('image_type', None)
@@ -443,7 +490,6 @@ class ImageChoiceField(ChoiceField):
 
 class NetworkChoiceField(ChoiceField):
     def __init__(self,
-                 include_subnets=True,
                  filter=None,
                  murano_networks=None,
                  allow_auto=True,
@@ -454,7 +500,6 @@ class NetworkChoiceField(ChoiceField):
             if murano_networks.lower() not in ["exclude", "translate"]:
                 raise ValueError(_("Invalid value of 'murano_nets' option"))
         self.murano_networks = murano_networks
-        self.include_subnets = include_subnets
         self.allow_auto = allow_auto
         super(NetworkChoiceField, self).__init__(*args,
                                                  **kwargs)
@@ -467,7 +512,6 @@ class NetworkChoiceField(ChoiceField):
         rendered
         """
         network_choices = net.get_available_networks(request,
-                                                     self.include_subnets,
                                                      self.filter,
                                                      self.murano_networks)
         if self.allow_auto:
@@ -505,6 +549,44 @@ class AZoneChoiceField(ChoiceField):
         self.choices = az_choices
 
 
+class VolumeChoiceField(ChoiceField):
+    def __init__(self,
+                 include_snapshots=True,
+                 *args,
+                 **kwargs):
+        self.include_snapshots = include_snapshots
+        super(VolumeChoiceField, self).__init__(*args, **kwargs)
+
+    @with_request
+    def update(self, request, **kwargs):
+        """This widget allows selection of Volumes and Volume Snapshots"""
+        available = {'status': cinder.VOLUME_STATE_AVAILABLE}
+        try:
+            choices = [(volume.id, volume.name)
+                       for volume in cinder.volume_list(request,
+                       search_opts=available)]
+        except Exception:
+            choices = []
+            exceptions.handle(request,
+                              _("Unable to retrieve volume list."))
+
+        if self.include_snapshots:
+            try:
+                choices.extend((snap.id, snap.name)
+                               for snap in cinder.volume_snapshot_list(request,
+                               search_opts=available))
+            except Exception:
+                exceptions.handle(request,
+                                  _("Unable to retrieve snapshot list."))
+
+        if choices:
+            choices.sort(key=lambda e: e[1])
+            choices.insert(0, ("", _("Select volume")))
+        else:
+            choices.insert(0, ("", _("No volumes available")))
+        self.choices = choices
+
+
 class BooleanField(forms.BooleanField, CustomPropertiesField):
     def __init__(self, *args, **kwargs):
         if 'widget' in kwargs:
