@@ -50,11 +50,12 @@ TYPES.update({
     'network': fields.NetworkChoiceField,
     'text': (fields.CharField, forms.Textarea),
     'choice': fields.ChoiceField,
-    'floatingip': fields.FloatingIpBooleanField
+    'floatingip': fields.FloatingIpBooleanField,
+    'securitygroup': fields.SecurityGroupChoiceField,
+    'volume': fields.VolumeChoiceField
 })
 
-# From Horizon project/instances/workflow/create_instance
-KEYPAIR_IMPORT_URL = "horizon:project:access_and_security:keypairs:import"
+KEYPAIR_IMPORT_URL = "horizon:project:key_pairs:import"
 TYPES_KWARGS = {
     'keypair': {'add_item_link': KEYPAIR_IMPORT_URL}
 }
