@@ -126,6 +126,8 @@ class Service(object):
     def extract_attributes(self):
         context = self.context.create_child_context()
         context['$'] = self.cleaned_data
+        context['$forms'] = self.cleaned_data
+
         for name, template in six.iteritems(self.templates):
             context[name] = template
         if semantic_version.Version.coerce(self.spec_version) \
@@ -255,7 +257,7 @@ def get_app_forms(request, kwargs):
         return _get_form_name(i, form, _('Step {0}'))
 
     step_names = [get_form_name(*pair) for pair in enumerate(app.forms)]
-    return zip(step_names, app.forms)
+    return list(zip(step_names, app.forms))
 
 
 def service_type_from_id(service_id):
