@@ -134,7 +134,7 @@ class DetailServiceView(tabs.TabbedTableView):
             (context["environment_name"],
              reverse("horizon:app-catalog:environments:services",
                      args=[self.environment_id])),
-            (_('Applications'),), ]
+            (_('Applications'), None)]
         context["custom_breadcrumb"] = breadcrumb
         return context
 
@@ -174,9 +174,10 @@ class CreateEnvironmentView(views.ModalFormView):
     submit_url = reverse_lazy(
         'horizon:app-catalog:environments:create_environment')
 
-    def get_form(self, form_class):
+    def get_form(self, **kwargs):
         if 'next' in self.request.GET:
             self.request.session['next_url'] = self.request.GET['next']
+        form_class = kwargs.get('form_class', self.get_form_class())
         return super(CreateEnvironmentView, self).get_form(form_class)
 
     def get_success_url(self):
@@ -190,6 +191,26 @@ class CreateEnvironmentView(views.ModalFormView):
         return reverse_lazy('horizon:app-catalog:environments:index')
 
 
+class DeploymentHistoryView(tables.DataTableView):
+    table_class = env_tables.DeploymentHistoryTable
+    template_name = 'environments/index.html'
+    page_title = _("Deployment History")
+
+    def get_data(self):
+        deployment_history = []
+        try:
+            deployment_history = api.deployment_history(self.request)
+        except exc.HTTPUnauthorized:
+            exceptions.handle(self.request)
+        except exc.HTTPForbidden:
+            redirect = reverse('horizon:app-catalog:environments:services',
+                               args=[self.environment_id])
+            exceptions.handle(self.request,
+                              _('Unable to retrieve deployment history.'),
+                              redirect=redirect)
+        return deployment_history
+
+
 class DeploymentDetailsView(tabs.TabbedTableView):
     tab_group_class = env_tabs.DeploymentDetailsTabs
     table_class = env_tables.EnvConfigTable
