@@ -27,9 +27,14 @@ LOG = logging.getLogger(__name__)
 
 
 def filter_murano_images(images, request=None):
+    # filter out the snapshot image type
+    images = filter(
+        lambda x: getattr(x, 'image_type', None) != 'snapshot', list(images))
     marked_images = []
     for image in images:
-        metadata = image.properties.get('murano_image_info')
+        # Additional properties, whose value is always a string data type, are
+        # only included in the response if they have a value.
+        metadata = getattr(image, 'murano_image_info', None)
         if metadata:
             try:
                 metadata = json.loads(metadata)
@@ -54,13 +59,15 @@ class MarkImageForm(horizon_forms.SelfHandlingForm):
         'custom': "Custom type"
     }
 
-    image = forms.ChoiceField(label=_('Image'))
+    image = forms.ChoiceField(
+        label=_('Image'),
+        widget=horizon_forms.ThemableSelectWidget())
     title = forms.CharField(max_length="255", label=_("Title"))
     type = forms.ChoiceField(
         label=_("Type"),
         choices=_metadata.items(),
         initial='custom',
-        widget=forms.Select(attrs={
+        widget=horizon_forms.ThemableSelectWidget(attrs={
             'class': 'switchable',
             'data-slug': 'type'}))
     custom_type = forms.CharField(
@@ -90,6 +97,10 @@ class MarkImageForm(horizon_forms.SelfHandlingForm):
         images = filter(
             lambda x: x.container_format not in ('aki', 'ari'), images)
 
+        # filter out the snapshot image type
+        images = filter(
+            lambda x: x.properties.get("image_type", '') != 'snapshot', images)
+
         self.fields['image'].choices = [(i.id, i.name) for i in images]
         self.fields['existing_titles'].initial = \
             [image.title for image in filter_murano_images(images)]
