@@ -36,6 +36,7 @@ EnvStatus = "//tr[contains(@data-display, '{0}')]/td[contains(text(), '{1}')]"
 CellStatus = "//td[contains(@class, 'status_{0}')]"
 Row = "//tr[contains(@id, 'services__row__{0}')]"
 ErrorMessage = '//span[contains(@class, "help-block") and contains(text(), "{0}")]'  # noqa
+JsErrorMessage = '//div[contains(@class, "alert-danger") and contains(text(), "{0}")]'  # noqa
 EnvAppsCategory = "//div[contains(@class, 'draggable_app')]//div[contains(text(), '{0}')]"  # noqa
 PackageCategory = "//select[@name='add_category-categories']/option[text()='{0}']"  # noqa
 DatabaseCategory = "select[name='add_category-categories'] > option[value='Databases']"  # noqa
@@ -57,6 +58,8 @@ TableDropdownAction = "//tr[contains(@data-display, '{0}')]//button[contains("\
 # Buttons
 ButtonSubmit = ".//*[@name='wizard_goto_step'][2]"
 InputSubmit = "//input[@type='submit']"
+NextWizardSubmit = 'div.modal-footer input[value="Next"]'
+CreateWizardSubmit = 'div.modal-footer input[value="Create"]'
 ConfirmDeletion = "//div[@class='modal-footer']//a[contains(text(), 'Delete')]"  # noqa
 ConfirmAbandon = "//div[@class='modal-footer']//a[contains(text(), 'Abandon')]"  # noqa
 UploadPackage = 'packages__action_upload_package'
@@ -88,9 +91,10 @@ DeploymentHistoryLogs = "div#environment_details__env_logs div.reports.logs "\
                         "div.report-info"
 PackageFilterDropdownBtn = 'div.table_search > div.themable-select.dropdown >'\
                            ' button'
-PackageFilterTypeBtn = "a[data-select-value='{0}']"
 PackageFilterInput = 'input[name="packages__filter_packages__q"]'
 PackageFilterBtn = "packages__action_filter_packages"
+ThemableSelect = 'label[for$="{0}"] ~ div div button.dropdown-toggle'
+ThemableOption = "a[data-select-value='{0}']"
 
 # Panels
 AppCatalog = "//*[@id='main_content']/nav//a[contains(text(), 'App Catalog')]"  # noqa
