@@ -129,9 +129,9 @@ class TestFields(testtools.TestCase):
     @mock.patch.object(fields, 'glance')
     def test_get_murano_images(self, mock_glance):
         foo_image = mock.Mock(murano_property=None)
-        foo_image.properties = {"murano_image_info": '{"foo": "foo_val"}'}
+        foo_image.murano_image_info = '{"foo": "foo_val"}'
         bar_image = mock.Mock(murano_property=None)
-        bar_image.properties = {"murano_image_info": '{"bar": "bar_val"}'}
+        bar_image.murano_image_info = '{"bar": "bar_val"}'
         mock_glance.image_list_detailed.return_value = [
             [foo_image, bar_image], None
         ]
@@ -168,7 +168,7 @@ class TestFields(testtools.TestCase):
     def test_murano_images_except_value_error(self, mock_glance, mock_log,
                                               mock_messages):
         foo_image = mock.Mock(murano_property=None)
-        foo_image.properties = {"murano_image_info": "{'foo': 'foo_val'}"}
+        foo_image.murano_image_info = "{'foo': 'foo_val'}"
         mock_glance.image_list_detailed.return_value = [
             [foo_image], None
         ]
@@ -576,6 +576,31 @@ class TestKeyPairChoiceField(testtools.TestCase):
                          sorted(key_pair_choice_field.choices))
 
 
+class TestSecurityGroupChoiceField(testtools.TestCase):
+
+    def setUp(self):
+        super(TestSecurityGroupChoiceField, self).setUp()
+        self.request = {'request': mock.Mock()}
+        self.addCleanup(mock.patch.stopall)
+
+    @mock.patch.object(fields, 'neutron')
+    def test_update(self, mock_neutron):
+        mock_neutron.security_group_list.return_value = [
+            mock.Mock(name_or_id='foo'),
+            mock.Mock(name_or_id='bar')
+        ]
+        security_group_choice_field = fields.SecurityGroupChoiceField()
+        security_group_choice_field.choices = []
+        security_group_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('Application default security group')),
+            ('foo', 'foo'), ('bar', 'bar')
+        ]
+        self.assertEqual(sorted(expected_choices),
+                         sorted(security_group_choice_field.choices))
+
+
 class TestImageChoiceField(testtools.TestCase):
 
     def setUp(self):
@@ -623,7 +648,6 @@ class TestNetworkChoiceField(testtools.TestCase):
     def setUp(self):
         super(TestNetworkChoiceField, self).setUp()
         self.network_choice_field = fields.NetworkChoiceField(
-            include_subnets=True,
             filter=None,
             murano_networks='exclude',
             allow_auto=True)
@@ -642,7 +666,7 @@ class TestNetworkChoiceField(testtools.TestCase):
         self.network_choice_field.update(self.request)
         self.assertEqual(expected_choices, self.network_choice_field.choices)
         mock_net.get_available_networks.assert_called_once_with(
-            self.request['request'], True, None, 'exclude')
+            self.request['request'], None, 'exclude')
 
     def test_to_python(self):
         self.assertEqual({'foo': 'bar'},
@@ -651,6 +675,126 @@ class TestNetworkChoiceField(testtools.TestCase):
                          self.network_choice_field.to_python(None))
 
 
+class TestVolumeChoiceField(testtools.TestCase):
+
+    def setUp(self):
+        super(TestVolumeChoiceField, self).setUp()
+        self.request = {'request': mock.Mock()}
+        self.addCleanup(mock.patch.stopall)
+
+    @mock.patch.object(fields, 'cinder')
+    def test_update(self, mock_cinder):
+        foo_vol = mock.Mock()
+        bar_snap = mock.Mock()
+        baz_snap = mock.Mock()
+        foo_vol.configure_mock(name='foo_vol', id='foo_id', status='available')
+        bar_snap.configure_mock(name='bar_snap', id='bar_id',
+                                status='available')
+        baz_snap.configure_mock(name='baz_snap', id='baz_id', status='error')
+        mock_cinder.volume_list.return_value = [foo_vol]
+        mock_cinder.volume_snapshot_list.return_value = [bar_snap]
+        volume_choice_field = fields.VolumeChoiceField(include_snapshots=True)
+        volume_choice_field.choices = []
+        volume_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('Select volume')), ('foo_id', 'foo_vol'),
+            ('bar_id', 'bar_snap')
+        ]
+
+        self.assertEqual(sorted(expected_choices),
+                         sorted(volume_choice_field.choices))
+
+    @mock.patch.object(fields, 'cinder')
+    def test_update_withoutsnapshot(self, mock_cinder):
+        foo_vol = mock.Mock()
+        bar_vol = mock.Mock()
+        baz_snap = mock.Mock()
+        foo_vol.configure_mock(name='foo_vol', id='foo_id', status='available')
+        bar_vol.configure_mock(name='bar_vol', id='bar_id', status='error')
+        baz_snap.configure_mock(name='baz_snap', id='baz_id',
+                                status='available')
+        mock_cinder.volume_list.return_value = [foo_vol]
+        mock_cinder.volume_snapshot_list.return_value = [baz_snap]
+        volume_choice_field = fields.VolumeChoiceField(include_snapshots=False)
+        volume_choice_field.choices = []
+        volume_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('Select volume')), ('foo_id', 'foo_vol')
+        ]
+
+        self.assertEqual(sorted(expected_choices),
+                         sorted(volume_choice_field.choices))
+
+    @mock.patch.object(fields, 'exceptions')
+    @mock.patch.object(fields, 'cinder')
+    def test_update_except_snapshot_list_exception(self, mock_cinder,
+                                                   mock_exceptions):
+        foo_vol = mock.Mock()
+        bar_vol = mock.Mock()
+        foo_vol.configure_mock(name='foo_vol', id='foo_id', status='available')
+        bar_vol.configure_mock(name='bar_vol', id='bar_id', status='error')
+        mock_cinder.volume_list.return_value = [foo_vol]
+        mock_cinder.volume_snapshot_list.side_effect = Exception
+        volume_choice_field = fields.VolumeChoiceField(include_snapshots=True)
+        volume_choice_field.choices = []
+        volume_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('Select volume')), ('foo_id', 'foo_vol')
+        ]
+
+        self.assertEqual(sorted(expected_choices),
+                         sorted(volume_choice_field.choices))
+        mock_exceptions.handle.assert_called_once_with(
+            self.request['request'], _('Unable to retrieve snapshot list.'))
+
+    @mock.patch.object(fields, 'exceptions')
+    @mock.patch.object(fields, 'cinder')
+    def test_update_except_volume_list_exception(self, mock_cinder,
+                                                 mock_exceptions):
+        bar_snap = mock.Mock()
+        baz_snap = mock.Mock()
+        bar_snap.configure_mock(name='bar_snap', id='bar_id',
+                                status='available')
+        baz_snap.configure_mock(name='baz_snap', id='baz_id', status='error')
+        mock_cinder.volume_list.side_effect = Exception
+        mock_cinder.volume_snapshot_list.return_value = [bar_snap]
+        volume_choice_field = fields.VolumeChoiceField(include_snapshots=True)
+        volume_choice_field.choices = []
+        volume_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('Select volume')), ('bar_id', 'bar_snap')
+        ]
+
+        self.assertEqual(expected_choices, volume_choice_field.choices)
+        mock_exceptions.handle.assert_called_once_with(
+            self.request['request'], _('Unable to retrieve volume list.'))
+
+    @mock.patch.object(fields, 'exceptions')
+    @mock.patch.object(fields, 'cinder')
+    def test_update_except_exception(self, mock_cinder, mock_exceptions):
+        mock_cinder.volume_list.side_effect = Exception
+        mock_cinder.volume_snapshot_list.side_effect = Exception
+        volume_choice_field = fields.VolumeChoiceField(include_snapshots=True)
+        volume_choice_field.choices = []
+        volume_choice_field.update(self.request)
+
+        expected_choices = [
+            ('', _('No volumes available'))
+        ]
+        expected_calls = [
+            mock.call(self.request['request'],
+                      _('Unable to retrieve volume list.')),
+            mock.call(self.request['request'],
+                      _('Unable to retrieve snapshot list.'))
+        ]
+        self.assertEqual(expected_choices, volume_choice_field.choices)
+        mock_exceptions.handle.assert_has_calls(expected_calls)
+
+
 class TestAZoneChoiceField(testtools.TestCase):
 
     @mock.patch.object(fields, 'nova')
